@@ -59,15 +59,16 @@ pub(super) fn derive(salt: &[u8], ikm: &[u8]) -> ([u8; 32], [u8; 32]) {
     // T(2) = HMAC-Hash(PRK, T(1) | info | 0x02)
     let t2 = hmac_sha256!(&prk, (&t1, &[2]));
 
-    return (t1, t2);
+    (t1, t2)
 }
 
 // Appendix A.  Test Vectors
 #[cfg(test)]
 mod test {
-    use super::derive;
     use amplify::hex::FromHex;
 
+    use super::derive;
+
     // Test with SHA-256 and zero-length salt/info
     // Our implementation uses a zero-length info field and returns the first 64
     // octets. As a result, this test will be a prefix match on the vector
